/**
 * TicketMachine models a naive ticket machine that issues
 * flat-fare tickets.
 * The price of a ticket is specified via the constructor.
 * It is a naive machine in the sense that it trusts its users
 * to insert enough money before trying to print a ticket.
 * It also assumes that users enter sensible amounts.
 *
 * @author David J. Barnes and Michael Kolling
 * @version 2008.03.30
 */
class TicketMachine
{
    // The price of a ticket from this machine.
    private int price;
    // The amount of money entered by a customer so far.
    private int balance;
    // The total amount of money collected by this machine.
    private int total;
    // The amount of money taken off of a payment
    private int discount;
    // The amount of money being saved by user
    private int saving;
    //The value of total divided by count
    private int mean;
    //the value divided by total to get mean
    private int count;
    private int budget;

    /**
     * Create a machine that issues tickets of the given price.
     * Note that the price must be greater than zero, and there
     * are no checks to ensure this.
     */
    public TicketMachine()
    {
        price = 0;
        balance = 0;
        total = 0;
        discount = (int)(.10);
        mean = 0;
        count = 500;
        budget = 0;
    }

    /**
     * Return the price of a ticket.
     */
    public int getPrice()
    {
        return price;
    }

    public int setPrice(int newPrice)
    {
        return newPrice;
    }

    /**
     * Return the amount of money already inserted for the
     * next ticket.
     */
    public int getBalance()
    {
        return balance;
    }

    /**
     * Receive an amount of money in cents from a customer.
     */
    public void insertMoney(int amount)
    {
        balance = balance + amount;
    }

    /**
     * Returns total amount of money this machine has collected
     */
    public int getTotal()
    {
        return total;
    }

    /**
     * Print a ticket.
     * Update the total collected and
     * reduce the balance to zero.
     */
    public void printTicket()
    {
        // Simulate the printing of a ticket.
        System.out.println("##################");
        System.out.println("# The BlueJ Line");
        System.out.println("# Ticket");
        System.out.println("# " + price + " cents.");
        System.out.println("##################");
        System.out.println();
        
        mean = total / count;
        //Update the total combined with discount.
        saving = price * discount;
        // Update the total collected with the balance.
        total = total + balance;
        // Clear the balance.
        balance = 0;
        
        if (price > budget){
            System.out.println("Too expensive. Your budget is: " + budget + ".");
    } else {
        System.out.println("Just right.");
    }
    }

    public void prompt()
    {
        System.out.println("Please insert the correct amount of money.");
    }

    public void showPrice(int ticketPrice)
    { 
        System.out.println("The price of a ticket is " + price + " cents.");
    }

    public void empty()
    {
        total = 0;
    }
   
}